==> neo4j-java-driver-4.3.3-sources.jar: org/neo4j/driver/internal/DatabaseNameUtil.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal;

import java.util.Objects;
import java.util.Optional;

public final class DatabaseNameUtil
{
    static final String DEFAULT_DATABASE_NAME = null;
    public static final String SYSTEM_DATABASE_NAME = "system";

    private static final DatabaseName DEFAULT_DATABASE = new DatabaseName()
    {
        @Override
        public Optional<String> databaseName()
        {
            return Optional.empty();
        }

        @Override
        public String description()
        {
            return "<default database>";
        }
    };
    private static final DatabaseName SYSTEM_DATABASE = new InternalDatabaseName( SYSTEM_DATABASE_NAME );

    public static DatabaseName defaultDatabase()
    {
        return DEFAULT_DATABASE;
    }

    public static DatabaseName systemDatabase()
    {
        return SYSTEM_DATABASE;
    }

    public static DatabaseName database( String name )
    {
        if ( Objects.equals( name, DEFAULT_DATABASE_NAME ) )
        {
            return defaultDatabase();
        }
        else if ( Objects.equals( name, SYSTEM_DATABASE_NAME ) )
        {
            return systemDatabase();
        }
        return new InternalDatabaseName( name );
    }
}

==> neo4j-java-driver-4.4.11-sources.jar: org/neo4j/driver/internal/DatabaseNameUtil.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal;

import java.util.Objects;
import java.util.Optional;

public final class DatabaseNameUtil {
    static final String DEFAULT_DATABASE_NAME = null;
    public static final String SYSTEM_DATABASE_NAME = "system";

    private static final DatabaseName DEFAULT_DATABASE = new DatabaseName() {
        @Override
        public Optional<String> databaseName() {
            return Optional.empty();
        }

        @Override
        public String description() {
            return "<default database>";
        }
    };
    private static final DatabaseName SYSTEM_DATABASE = new InternalDatabaseName(SYSTEM_DATABASE_NAME);

    public static DatabaseName defaultDatabase() {
        return DEFAULT_DATABASE;
    }

    public static DatabaseName systemDatabase() {
        return SYSTEM_DATABASE;
    }

    public static DatabaseName database(String name) {
        if (Objects.equals(name, DEFAULT_DATABASE_NAME)) {
            return defaultDatabase();
        } else if (Objects.equals(name, SYSTEM_DATABASE_NAME)) {
            return systemDatabase();
        }
        return new InternalDatabaseName(name);
    }
}
